import { IPackageJson } from 'package-json-type';

declare class State {
    PACKAGE: IPackageJson;
    readonly CONFIG: ConfigFile;
    configPath: string;
    canCreateOrUpdateConfig: boolean;
    constructor(PACKAGE: IPackageJson, CONFIG: ConfigFile, configPath: string, canCreateOrUpdateConfig?: boolean);
    getConfigSection<T extends keyof ConfigFile>(type: T): Promise<ConfigFile[T]>;
}

declare function Badges(STATE: State): Promise<void>;
declare const BADGES: {
    /** circleCi build. */
    circleci: string;
    /** codecov percentage. */
    codecov: string;
    /** Vscode Extension Version. */
    vscV: string;
    /** Vscode Extension downloads. */
    vscD: string;
    /** Vscode Extension installs. */
    vscI: string;
    /** Vscode Extension ratings. */
    vscR: string;
    /** Bundlephobia Min. */
    min: string;
    /** Bundlephobia Minzip. */
    minzip: string;
    /** Packagephobia Install. */
    install: string;
    /** Packagephobia Publish. */
    publish: string;
    /** Npm Version. */
    npmV: string;
    /** Npm Weekly Downloads. */
    npmDW: string;
    /** Npm Monthly Downloads. */
    npmDM: string;
    /** Npm Yearly Downloads. */
    npmDY: string;
    /** Npm Total Downloads. */
    npmDT: string;
    /** Npm Types. */
    npmTypes: string;
    /** Npm License. */
    npmLicense: string;
    /** Npm Node. */
    npmNode: string;
    /** Npm Dependents. */
    npmDep: string;
    /** GitHub Followers. */
    githubFollowers: string;
    /** GitHub Forks. */
    githubForks: string;
    /** GitHub Starts. */
    githubStars: string;
    /** GitHub Issues. */
    githubIssues: string;
    /** GitHub Last Commit. */
    githubLastCommit: string;
};
type BadgeTypes = typeof BADGES;
declare const LINKS: {
    /** Npm package. */
    npm: string;
    /** Github Repo. */
    github: string;
    /** circleCi Repo Pipelines. */
    circleci: string;
    /** Visual Studio marketplace. */
    vscode: string;
    /** Bundlephobia Link. */
    bundle: string;
    /** Packagephobia Link. */
    package: string;
    /** codecov Link. */
    codecov: string;
};
type BadgeLinkTypes = typeof LINKS;

interface BadgesModuleConfig {
    /**package name */
    name: string;
    /**github username */
    github: string;
    /**vscode publisher.packageName */
    vscode?: string;
    /**github repo name */
    repo: string;
    /**path to readme or other target file */
    out?: string;
    /**Array of badges */
    badges: ([keyof BadgeTypes, keyof BadgeLinkTypes, string] | [keyof BadgeTypes, keyof BadgeLinkTypes] | `${keyof BadgeTypes} ${keyof BadgeLinkTypes}`)[];
    /**link to external config,(not sure if this still works) */
    externalConfig?: string;
}
interface TsDocModuleConfig {
    /**title displayed at the top of the generated text */
    title?: string;
    /**path to the d.ts files */
    dir: string;
    /**defaults to README.md */
    out: string;
    /**include all files in array, include and exclude cannot be used at the same time */
    include?: string[];
    /**exclude all files in array, include and exclude cannot be used at the same time */
    exclude?: string[];
}
interface LicenseModuleConfig {
    /**license type, can be found add https://api.github.com/licenses/TYPE */
    type: string;
    /**license year, use null for current year. */
    year: string | null | number;
    /**full name of the copyright holder */
    name: string;
    /**defaults to README.md */
    out?: string;
    /**defaults to LICENSE */
    file?: string;
}
interface ConfigFile {
    badges?: BadgesModuleConfig;
    tsDoc?: Partial<TsDocModuleConfig>;
    license?: LicenseModuleConfig;
}

declare function License(STATE: State): Promise<void>;

declare function TsDoc(STATE: State): Promise<void>;

export { Badges, ConfigFile, License, TsDoc };
